@@ -27,9 +27,7 @@
 #include <gnome.h>
 #include <string.h>
 
-#if 0
-#include <libgnomevfs/gnome-vfs-mime.h>
-#endif
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
 
 #if 0
 static char *help_pages[] = {
@@ -284,10 +282,12 @@ intro_page_ok (void)
 	if (! (s && strlen (s))) {
 		g_free (s);
 		w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-					    GTK_DIALOG_NO_SEPARATOR,
+					    0,
 					    GTK_MESSAGE_ERROR,
 					    GTK_BUTTONS_OK,
 					    _("Please enter your name."));
+		gtk_dialog_set_default_response (GTK_DIALOG (w),
+						 GTK_RESPONSE_OK);
 		gtk_dialog_run (GTK_DIALOG (w));
 		gtk_widget_destroy (w);
 		return FALSE;
@@ -298,10 +298,12 @@ intro_page_ok (void)
 	if (!email_is_valid (s)) {
 		g_free (s);
 		w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-					    GTK_DIALOG_NO_SEPARATOR,
+					    0,
 					    GTK_MESSAGE_ERROR,
 					    GTK_BUTTONS_OK,
 					    _("Please enter a valid email address."));
+		gtk_dialog_set_default_response (GTK_DIALOG (w),
+						 GTK_RESPONSE_OK);
 		gtk_dialog_run (GTK_DIALOG (w));
 		gtk_widget_destroy (w);
 		return FALSE;
@@ -313,7 +315,7 @@ intro_page_ok (void)
 		if (druid_data.submit_type == SUBMIT_TO_SELF ||
 		    druid_data.submit_type == SUBMIT_REPORT) {
 			w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-						    GTK_DIALOG_NO_SEPARATOR,
+						    0,
 						    GTK_MESSAGE_QUESTION,
 						    GTK_BUTTONS_YES_NO,
 						    _("'%s' doesn't seem to exist.\n\n"
@@ -321,8 +323,10 @@ intro_page_ok (void)
 						      "submit a bug report, but you will\n"
 						      "be able to save it to a file.\n\n"
 						      "Specify a new location for sendmail?"),
-						    s);	
-			if (GTK_RESPONSE_YES == gtk_dialog_run (GTK_DIALOG (w))) {
+						    s);
+			gtk_dialog_set_default_response (GTK_DIALOG (w),
+							 GTK_RESPONSE_YES);
+			if (GTK_RESPONSE_NO != gtk_dialog_run (GTK_DIALOG (w))) {
 				g_free (s);
 				gtk_widget_destroy (w);
 				return FALSE;
@@ -371,33 +375,36 @@ desc_page_ok (void)
 		const char *mime_type;
 		if (!g_file_test (s, G_FILE_TEST_EXISTS)) {
 			w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-						    GTK_DIALOG_NO_SEPARATOR,
+						    0,
 						    GTK_MESSAGE_ERROR,
 						    GTK_BUTTONS_OK,
 						    _("The specified file does not exist."));
+			gtk_dialog_set_default_response (GTK_DIALOG (w),
+							 GTK_RESPONSE_OK);
 			gtk_dialog_run (GTK_DIALOG (w));
 			gtk_widget_destroy (w);
 			g_free (s);
 			return FALSE;
 		}
-#if 0
-		mime_type = gnome_vfs_get_file_mime_type (s, NULL, FALSE);
+
+		mime_type = gnome_vfs_get_mime_type (s);
 		d(g_message (_("File is of type: %s"), mime_type));
 		
 		if (strncmp ("text/", mime_type, 5)) {
 			w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-						    GTK_DIALOG_NO_SEPARATOR,
+						    0,
 						    GTK_MESSAGE_ERROR,
 						    GTK_BUTTONS_OK,
 						    _("'%s' is a %s file.\n\n"
 						      "Bug Buddy can only submit plaintext (text/*) files."),
 						    s, mime_type);
+			gtk_dialog_set_default_response (GTK_DIALOG (w),
+							 GTK_RESPONSE_OK);
 			gtk_dialog_run (GTK_DIALOG (w));
 			gtk_widget_destroy (w);
 			g_free (s);
 			return FALSE;
 		}
-#endif
 	}
 	g_free (s);
 
@@ -405,10 +412,12 @@ desc_page_ok (void)
 	if (!text_is_sensical (s, 6)) {
 		g_free (s);
 		w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-					    GTK_DIALOG_NO_SEPARATOR,
+					    0,
 					    GTK_MESSAGE_ERROR,
 					    GTK_BUTTONS_OK,
 					    _("You must include a comprehensible subject line in your bug report."));
+		gtk_dialog_set_default_response (GTK_DIALOG (w),
+						 GTK_RESPONSE_OK);
 		gtk_dialog_run (GTK_DIALOG (w));
 		gtk_widget_destroy (w);
 		return FALSE;
@@ -419,10 +428,12 @@ desc_page_ok (void)
 	if (!text_is_sensical (s, 8)) {
 		g_free (s);
 		w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-					    GTK_DIALOG_NO_SEPARATOR,
+					    0,
 					    GTK_MESSAGE_ERROR,
 					    GTK_BUTTONS_OK,
 					    _("You must include a comprehensible description in your bug report."));
+		gtk_dialog_set_default_response (GTK_DIALOG (w),
+						 GTK_RESPONSE_OK);
 		gtk_dialog_run (GTK_DIALOG (w));
 		gtk_widget_destroy (w);
 		return FALSE;
@@ -440,10 +451,12 @@ submit_ok (void)
 
 	if (druid_data.submit_type != SUBMIT_FILE) {
 		w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-					    GTK_DIALOG_NO_SEPARATOR,
+					    0,
 					    GTK_MESSAGE_QUESTION,
 					    GTK_BUTTONS_YES_NO,
 					    _("Submit this bug report now?"));
+		gtk_dialog_set_default_response (GTK_DIALOG (w),
+						 GTK_RESPONSE_YES);
 		if (GTK_RESPONSE_YES != gtk_dialog_run (GTK_DIALOG (w))) {
 			gtk_widget_destroy (w);
 			return FALSE;
@@ -460,13 +473,15 @@ submit_ok (void)
 		fp = fopen (file, "w");
 		if (!fp) {
 			w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-						    GTK_DIALOG_NO_SEPARATOR,
+						    0,
 						    GTK_MESSAGE_ERROR,
 						    GTK_BUTTONS_OK,
 						    _("Unable to open file '%s':\n%s"), 
 						    file, g_strerror (errno));
 			g_free (file);
 			g_free (to);
+			gtk_dialog_set_default_response (GTK_DIALOG (w),
+							 GTK_RESPONSE_OK);
 			gtk_dialog_run (GTK_DIALOG (w));
 			gtk_widget_destroy (w);
 			return FALSE;
@@ -481,11 +496,13 @@ submit_ok (void)
 		g_free (command);
 		if (!fp) {
 			w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-						    GTK_DIALOG_NO_SEPARATOR,
+						    0,
 						    GTK_MESSAGE_ERROR,
 						    GTK_BUTTONS_OK,
 						    _("Unable to start mail program '%s':\n%s"), 
 						    s, g_strerror (errno));
+			gtk_dialog_set_default_response (GTK_DIALOG (w),
+							 GTK_RESPONSE_OK);
 			gtk_dialog_run (GTK_DIALOG (w));
 			gtk_widget_destroy (w);
 			return FALSE;
@@ -586,10 +603,12 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 		druid_data.product = get_selected_row ("product-list", PRODUCT_DATA);
 		if (!druid_data.product) {
 			d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-						    GTK_DIALOG_NO_SEPARATOR,
+						    0,
 						    GTK_MESSAGE_ERROR,
 						    GTK_BUTTONS_OK,
 						    _("You must specify a product for your bug report."));
+			gtk_dialog_set_default_response (GTK_DIALOG (d),
+							 GTK_RESPONSE_OK);
 			gtk_dialog_run (GTK_DIALOG (d));
 			gtk_widget_destroy (d);
 			return;
@@ -601,10 +620,12 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 		druid_data.component = get_selected_row ("component-list", COMPONENT_DATA);
 		if (!druid_data.component) {
 			d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-						    GTK_DIALOG_NO_SEPARATOR,
+						    0,
 						    GTK_MESSAGE_ERROR,
 						    GTK_BUTTONS_OK,
 						    _("You must specify a component for your bug report."));
+			gtk_dialog_set_default_response (GTK_DIALOG (d),
+							 GTK_RESPONSE_OK);
 			gtk_dialog_run (GTK_DIALOG (d));
 			gtk_widget_destroy (d);
 			return;
@@ -613,10 +634,12 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 		if (!s[0] && !getenv ("BUG_ME_HARDER")) {
 			g_free (s);
 			d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-						    GTK_DIALOG_NO_SEPARATOR,
+						    0,
 						    GTK_MESSAGE_ERROR,
 						    GTK_BUTTONS_OK,
 						    _("You must specify a version for your bug report."));
+			gtk_dialog_set_default_response (GTK_DIALOG (d),
+							 GTK_RESPONSE_OK);
 			gtk_dialog_run (GTK_DIALOG (d));
 			gtk_widget_destroy (d);
 			return;
@@ -647,11 +670,13 @@ on_druid_cancel_clicked (GtkWidget *w, gpointer data)
 	GtkWidget *d;
 
 	d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-				    GTK_DIALOG_NO_SEPARATOR,
+				    0,
 				    GTK_MESSAGE_QUESTION,
 				    GTK_BUTTONS_YES_NO,
 				    _("Are you sure you want to cancel\n"
 				      "this bug report?"));
+	gtk_dialog_set_default_response (GTK_DIALOG (d),
+					 GTK_RESPONSE_YES);
 	if (GTK_RESPONSE_YES != gtk_dialog_run (GTK_DIALOG (d))) {
 		gtk_widget_destroy (d);
 		return;
